@@ -22,6 +22,10 @@ def _post_request(dst_url, data=None, json=None,
         if response.status_code in [500, 502]:
             time.sleep(backoff)
             backoff = 2*backoff if backoff < max_backoff else backoff
+        elif response.status_code in [402]:
+            msg = f'Dataset limit reached. Failed to upload samples. '
+            msg += f'Contact your account manager to upgrade your subscription'
+            raise ConnectionRefusedError(msg)
         # something went wrong
         elif not success:
             msg = f'Failed POST request to {dst_url} with status_code '
@@ -39,7 +43,7 @@ def _post_request(dst_url, data=None, json=None,
     return response
 
 
-def _put_request(dst_url, data,
+def _put_request(dst_url, data=None, params=None, json=None,
                  max_backoff=32, max_retries=5):
 
     counter = 0
@@ -47,7 +51,7 @@ def _put_request(dst_url, data,
     success = False
     while not success:
 
-        response = requests.put(dst_url, data)
+        response = requests.put(dst_url, data=data, json=json, params=params)
         success = (response.status_code == 200)
 
         # exponential backoff
@@ -68,7 +72,7 @@ def _put_request(dst_url, data,
         msg = f'The connection to the server at {dst_url} timed out. '
         raise RuntimeError(msg)
 
-    return response
+    return response.status_code == 200
 
 
 def _get_request(dst_url, params=None,
@@ -216,6 +220,34 @@ def upload_embedding(data: dict) -> bool:
     return response
 
 
+def put_image_type(dataset_id: str,
+                   token: str,
+                   img_type: str):
+    """Add the attribute imgType to the db dataset entry
+
+    Args:
+        dataset_id: Identifier of the dataset
+        token: The token for authenticating the request
+
+    Returns:
+        A boolean value indicating a successful put request
+
+    Raises:
+        RuntimeError if put was not successful
+    """
+    params = {
+        'token': token
+    }
+    data = {
+        'dataset': {
+            'imgType': img_type
+        }
+    }
+    dst_url = f'{SERVER_LOCATION}/users/datasets/{dataset_id}'
+    response = _put_request(dst_url, json=data, params=params)
+    return response
+
+
 def get_tags(dataset_id: str,
              token: str):
     payload = {'token': token}
@@ -259,3 +291,34 @@ def get_latest_version(version, timeout=1):
         return response.json()[0]
     except Exception:
         return None
+
+def get_user_quota(token):
+    """Returns a dictionary with the quota for a user
+
+    The quota defines limitations for the current user.
+    
+    Args:
+        token: A token to identify the user
+    """
+    dst_url = f'{SERVER_LOCATION}/users/quota'
+    payload = {'token': token}
+    try:
+        response = requests.get(dst_url, params=payload)
+        return response.json()
+    except Exception:
+        return None
+
+
+def get_embedding_summaries(dataset_id: str,
+                            token: str):
+    """pass
+
+    """
+    dst_url = f'{SERVER_LOCATION}/users/datasets/'
+    dst_url += f'{dataset_id}/embeddings/'
+    payload = {
+        'token': token,
+        'mode': 'summaries'
+    }
+    response = _get_request(dst_url, params=payload)
+    return response.json()
\ No newline at end of file
