@@ -1,8 +1,9 @@
 import os
 import copy
+import time
+import random
 
 import numpy as np
-import pandas as pd
 
 from itertools import islice
 from typing import List
@@ -12,8 +13,11 @@ from boris.api._communication import get_presigned_upload_url
 from boris.api._communication import upload_file_with_signed_url
 from boris.api._communication import upload_sample_with_metadata
 from boris.api._communication import upload_embedding
+from boris.api._communication import put_image_type
 from boris.api._communication import get_samples
 from boris.api._communication import get_tags
+from boris.api._communication import get_user_quota
+from boris.api._communication import get_embedding_summaries
 
 from boris.api._utils import get_thumbnail_from_img
 from boris.api._utils import check_image
@@ -21,7 +25,7 @@ from boris.api._utils import PIL_to_bytes
 
 from boris.data import BorisDataset
 from boris.utils import fit_pca
-from boris.utils import pandas_to_dict
+from boris.utils import load_embeddings_as_dict
 
 import tqdm
 import warnings
@@ -35,7 +39,8 @@ MAXIMUM_DATASET_SIZE = 25_000
 def upload_embeddings_from_csv(path_to_embeddings: str,
                                dataset_id: str,
                                token: str,
-                               max_upload: int = 32):
+                               max_upload: int = 32,
+                               embedding_name: str = 'default'):
     """Uploads embeddings from a csv file to the cloud solution
 
     Args:
@@ -47,8 +52,13 @@ def upload_embeddings_from_csv(path_to_embeddings: str,
         RuntimeError if there is an error during the upload
         of a batch of embeddings
     """
-    df = pd.read_csv(path_to_embeddings)
-    data = pandas_to_dict(df)
+
+
+    data, embeddings, _, _ = load_embeddings_as_dict(
+        path_to_embeddings,
+        embedding_name,
+        return_all=True,
+    )
 
     data['token'] = token
     data['datasetId'] = dataset_id
@@ -58,8 +68,15 @@ def upload_embeddings_from_csv(path_to_embeddings: str,
         msg = 'Forbidden upload to dataset with no existing tags.'
         raise RuntimeError(msg)
 
+    embedding_summaries = get_embedding_summaries(dataset_id, token)
+    embedding_names = [embedding['name'] for embedding in embedding_summaries]
+    if embedding_name in embedding_names:
+        msg = f'Forbidden upload: Embedding name {embedding_name} '
+        msg += 'already exists.'
+        raise RuntimeError(msg)
+
     # use pca to make 2d embeddings
-    transformer = fit_pca(df.values[:, 1:-1])
+    transformer = fit_pca(embeddings)
 
     def _make_2d_embedding(batch):
         batch_2d = copy.deepcopy(batch)
@@ -101,7 +118,7 @@ def upload_images_from_folder(path_to_folder: str,
                               dataset_id: str,
                               token: str,
                               max_workers: int = 8,
-                              max_requests: int = 8,
+                              max_requests: int = 32,
                               mode: str = 'thumbnails'):
     """Uploads images from a directory to the cloud solution
 
@@ -118,9 +135,12 @@ def upload_images_from_folder(path_to_folder: str,
     bds = BorisDataset(from_folder=path_to_folder)
     fnames = bds.get_filenames()
 
-    if len(fnames) > MAXIMUM_DATASET_SIZE:
+    api_max_dataset_size = get_user_quota(token)['maxDatasetSize']
+    max_dataset_size = min(api_max_dataset_size, MAXIMUM_DATASET_SIZE)
+
+    if len(fnames) > max_dataset_size:
         msg = f'Your dataset has {len(fnames)} samples which'
-        msg += f' is more than the allowed maximum of {MAXIMUM_DATASET_SIZE}'
+        msg += f' is more than the allowed maximum of {max_dataset_size}'
         raise ValueError(msg)
 
     tags = get_tags(dataset_id, token)
@@ -132,9 +152,13 @@ def upload_images_from_folder(path_to_folder: str,
 
     def _upload_single_image(fname):
 
+        # random delay of uniform[0, 0.01] seconds to prevent API bursts
+        rnd_delay = random.random() * 0.01
+        time.sleep(rnd_delay)
+
         # get PIL image handles, metadata, and check if corrupted
         metadata, is_corrupted = check_image(
-            os.path.join(path_to_folder, fname), mode=mode
+            os.path.join(path_to_folder, fname)
         )
 
         # filename is too long, cannot accept this file
@@ -183,6 +207,7 @@ def upload_images_from_folder(path_to_folder: str,
                 signed_url = get_presigned_upload_url(
                     basename, dataset_id, sample_id, token
                 )
+
                 # try to upload image
                 image_path = os.path.join(path_to_folder, fname)
                 with open(image_path, 'rb') as temp_image:
@@ -218,6 +243,14 @@ def upload_images_from_folder(path_to_folder: str,
             msg += 'Failed at file: {}'.format(mapped.index(False))
             warnings.warn(msg)
         pbar.update(len(batch))
+
+    # set image type of data and create initial tag
+    if mode == 'full':
+        put_image_type(dataset_id, token, mode)
+    elif mode == 'thumbnails':
+        put_image_type(dataset_id, token, 'thumbnail')
+    else:
+        put_image_type(dataset_id, token, 'meta')
     create_initial_tag(dataset_id, token)
 
 
