@@ -3,6 +3,27 @@ import torch
 
 from hydra import utils
 
+import warnings
+
+
+def fix_from_folder(cfg):
+    if cfg['from_folder']:
+        cfg['input_dir'] = cfg['from_folder']
+        msg = 'Argument "from_folder" is deprecated and will be removed in 0.1.13!'
+        msg += ' Use "input_dir" instead.'
+        warnings.warn(msg)
+    if cfg['path_to_folder']:
+        cfg['input_dir'] = cfg['path_to_folder']
+        msg = 'Argument "path_to_folder" is deprecated and will be removed in 0.1.13!'
+        msg += ' Use "input_dir" instead.'
+        warnings.warn(msg)
+    if cfg['path_to_embeddings']:
+        cfg['embeddings'] = cfg['path_to_embeddings']
+        msg = 'Argument "path_to_embeddings" is deprecated and will be removed in 0.1.13!'
+        msg += ' Use "embeddings" instead.'
+        warnings.warn(msg)
+
+    return
 
 def fix_input_path(path):
     """Fix broken relative paths.
@@ -49,6 +70,9 @@ def _model_zoo(model):
         'resnet-34/simclr/d16/w1.0':
         'https://storage.googleapis.com/models_boris/whattolabel-resnet34-simclr-d16-w1.0-i-6e80d963.pth',
 
+        'resnet-34/simclr/d32/w1.0':
+        'https://storage.googleapis.com/models_boris/whattolabel-resnet34-simclr-d32-w1.0-i-9f185b45.pth'
+
     }
 
     key = model['name']
