@@ -20,6 +20,8 @@ import hydra
 
 from boris.cli.train_cli import _train_cli
 from boris.cli.embed_cli import _embed_cli
+from boris.cli.upload_cli import _upload_cli
+from boris.cli._helpers import fix_from_folder
 
 
 def _boris_cli(cfg, is_cli_call=True):
@@ -39,10 +41,13 @@ def _boris_cli(cfg, is_cli_call=True):
     cfg['loader']['drop_last'] = False
     cfg['checkpoint'] = checkpoint
 
-    return _embed_cli(cfg, is_cli_call)
+    embeddings = _embed_cli(cfg, is_cli_call)
+    cfg['embeddings'] = embeddings
+    if cfg['token'] and cfg['dataset_id']:
+        _upload_cli(cfg)   
 
 
-@hydra.main(config_path="config/config.yaml", strict=False)
+@hydra.main(config_path="config", config_name="config")
 def boris_cli(cfg):
     """Train a self-supervised model and use it to embed your dataset
 
@@ -51,6 +56,7 @@ def boris_cli(cfg):
         https://www.notion.so/whattolabel/WhatToLabel-Documentation-28e645f5564a453e807d0a384a4e6ea7
 
     """
+    fix_from_folder(cfg)
     return _boris_cli(cfg)
 
 
