@@ -25,12 +25,13 @@ import torchvision
 from boris.data import BorisDataset
 from boris.embedding import SelfSupervisedEmbedding
 from boris.models import ResNetSimCLR
-from boris.utils import embeddings_to_pandas
+from boris.utils import save_embeddings
 
 from boris.cli._helpers import _model_zoo
 from boris.cli._helpers import fix_input_path
 from boris.cli._helpers import filter_state_dict
 from boris.cli._helpers import load_state_dict_from_url
+from boris.cli._helpers import fix_from_folder
 
 
 def _embed_cli(cfg, is_cli_call=True):
@@ -41,7 +42,7 @@ def _embed_cli(cfg, is_cli_call=True):
         cfg[root]: (str) Directory where the dataset should be stored
         cfg[checkpoint]: (str) Path to the lightning checkpoint
         cfg[download]: (bool) Whether to download the dataset
-        cfg[from_folder]: (str) If specified, the dataset is loaded \
+        cfg[input_dir]: (str) If specified, the dataset is loaded \
             from the folder
 
     Returns:
@@ -59,9 +60,9 @@ def _embed_cli(cfg, is_cli_call=True):
     if root and is_cli_call:
         root = fix_input_path(root)
 
-    from_folder = cfg['from_folder']
-    if from_folder and is_cli_call:
-        from_folder = fix_input_path(from_folder)
+    input_dir = cfg['input_dir']
+    if input_dir and is_cli_call:
+        input_dir = fix_input_path(input_dir)
 
     torch.backends.cudnn.deterministic = True
     torch.backends.cudnn.benchmark = False
@@ -84,7 +85,7 @@ def _embed_cli(cfg, is_cli_call=True):
 
     dataset = BorisDataset(root,
                            name=data, train=True, download=download,
-                           from_folder=from_folder, transform=transform)
+                           from_folder=input_dir, transform=transform)
 
     cfg['loader']['drop_last'] = False
     cfg['loader']['shuffle'] = False
@@ -120,15 +121,16 @@ def _embed_cli(cfg, is_cli_call=True):
     encoder = SelfSupervisedEmbedding(model, None, None, None)
     embeddings, labels, filenames = encoder.embed(dataloader, device=device)
 
-    df = embeddings_to_pandas(embeddings, labels, filenames)
-    path = os.path.join(os.getcwd(), 'embeddings.csv')
-    df.to_csv(path, index=False)
-    print('Embeddings are stored at %s' % (path))
+    if is_cli_call:
+        path = os.path.join(os.getcwd(), 'embeddings.csv')
+        save_embeddings(path, embeddings, labels, filenames)
+        print('Embeddings are stored at %s' % (path))
+        return path
 
     return embeddings, labels, filenames
 
 
-@hydra.main(config_path='config/config.yaml', strict=False)
+@hydra.main(config_path='config', config_name='config')
 def embed_cli(cfg):
     """Use the trained self-supervised model to embed samples from your dataset.
 
@@ -137,7 +139,7 @@ def embed_cli(cfg):
         cfg[root]: (str) Directory where the dataset should be stored
         cfg[checkpoint]: (str) Path to the lightning checkpoint
         cfg[download]: (bool) Whether to download the dataset
-        cfg[from_folder]: (str) If specified, the dataset is loaded \
+        cfg[input_dir]: (str) If specified, the dataset is loaded \
             from the folder
 
     Returns:
@@ -146,7 +148,7 @@ def embed_cli(cfg):
         labels: (np.ndarray) Data labels, 0 if there are no labels
         filenames: (List[str]) File name of each data sample
     """
-
+    fix_from_folder(cfg)
     return _embed_cli(cfg)
 
 
