@@ -30,6 +30,7 @@ from boris.cli._helpers import _model_zoo
 from boris.cli._helpers import fix_input_path
 from boris.cli._helpers import filter_state_dict
 from boris.cli._helpers import load_state_dict_from_url
+from boris.cli._helpers import fix_from_folder
 
 import torch
 
@@ -42,7 +43,7 @@ def _train_cli(cfg, is_cli_call=True):
             Name of the dataset (to download use cifar10 or cifar100)
         cfg[root]: (str) Directory where the dataset should be stored
         cfg[download]: (bool) Whether to download the dataset
-        cfg[from_folder]: (str)
+        cfg[input_dir]: (str)
             If specified, the dataset is loaded from the folder
 
     Returns:
@@ -57,9 +58,9 @@ def _train_cli(cfg, is_cli_call=True):
     if root and is_cli_call:
         root = fix_input_path(root)
 
-    from_folder = cfg['from_folder']
-    if from_folder and is_cli_call:
-        from_folder = fix_input_path(from_folder)
+    input_dir = cfg['input_dir']
+    if input_dir and is_cli_call:
+        input_dir = fix_input_path(input_dir)
 
     if 'seed' in cfg.keys():
         seed = cfg['seed']
@@ -118,7 +119,7 @@ def _train_cli(cfg, is_cli_call=True):
 
     dataset = BorisDataset(root,
                            name=data, train=True, download=download,
-                           from_folder=from_folder)
+                           from_folder=input_dir)
 
     cfg['loader']['batch_size'] = min(
         cfg['loader']['batch_size'],
@@ -137,7 +138,7 @@ def _train_cli(cfg, is_cli_call=True):
     return encoder.checkpoint
 
 
-@hydra.main(config_path="config/config.yaml", strict=False)
+@hydra.main(config_path="config", config_name="config")
 def train_cli(cfg):
     """Train a self-supervised model on the image dataset of your choice.
 
@@ -146,14 +147,14 @@ def train_cli(cfg):
             Name of the dataset (to download use cifar10 or cifar100)
         cfg[root]: (str) Directory where the dataset should be stored
         cfg[download]: (bool) Whether to download the dataset
-        cfg[from_folder]: (str)
+        cfg[input_dir]: (str)
             If specified, the dataset is loaded from the folder
 
     Returns:
         checkpoint: (str) Path to checkpoint of the best model during training
 
     """
-
+    fix_from_folder(cfg)
     return _train_cli(cfg)
 
 
