@@ -3,6 +3,7 @@
     The boris.utils module provides commonly used utility methods
 """
 
-from ._format_conversion import embeddings_to_pandas
-from ._format_conversion import pandas_to_dict
+from ._io import save_embeddings
+from ._io import load_embeddings
+from ._io import load_embeddings_as_dict
 from ._2d_embeddings import fit_pca
